Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(35)

Unified Diff: src/arm64/codegen-arm64.cc

Issue 207823003: Rename A64 port to ARM64 port (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: retry Created 6 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/arm64/codegen-arm64.h ('k') | src/arm64/constants-arm64.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/arm64/codegen-arm64.cc
diff --git a/src/a64/codegen-a64.cc b/src/arm64/codegen-arm64.cc
similarity index 98%
rename from src/a64/codegen-a64.cc
rename to src/arm64/codegen-arm64.cc
index 32b32757817693ca5d20b94248db6c5002180d0e..831d44986259c475275d9bb1da30114dd202af06 100644
--- a/src/a64/codegen-a64.cc
+++ b/src/arm64/codegen-arm64.cc
@@ -27,11 +27,11 @@
#include "v8.h"
-#if V8_TARGET_ARCH_A64
+#if V8_TARGET_ARCH_ARM64
#include "codegen.h"
#include "macro-assembler.h"
-#include "simulator-a64.h"
+#include "simulator-arm64.h"
namespace v8 {
namespace internal {
@@ -39,14 +39,14 @@ namespace internal {
#define __ ACCESS_MASM(masm)
#if defined(USE_SIMULATOR)
-byte* fast_exp_a64_machine_code = NULL;
+byte* fast_exp_arm64_machine_code = NULL;
double fast_exp_simulator(double x) {
Simulator * simulator = Simulator::current(Isolate::Current());
Simulator::CallArgument args[] = {
Simulator::CallArgument(x),
Simulator::CallArgument::End()
};
- return simulator->CallDouble(fast_exp_a64_machine_code, args);
+ return simulator->CallDouble(fast_exp_arm64_machine_code, args);
}
#endif
@@ -92,7 +92,7 @@ UnaryMathFunction CreateExpFunction() {
#if !defined(USE_SIMULATOR)
return FUNCTION_CAST<UnaryMathFunction>(buffer);
#else
- fast_exp_a64_machine_code = buffer;
+ fast_exp_arm64_machine_code = buffer;
return &fast_exp_simulator;
#endif
}
@@ -546,7 +546,7 @@ void MathExpGenerator::EmitMathExp(MacroAssembler* masm,
// Continue the common case first. 'mi' tests N == 1.
__ B(&result_is_finite_non_zero, mi);
// TODO(jbramley): Consider adding a +infinity register for A64.
__ Ldr(double_temp2, ExpConstant(constants, 2)); // Synthesize +infinity.
// Select between +0.0 and +infinity. 'lo' tests C == 0.
@@ -612,4 +612,4 @@ void MathExpGenerator::EmitMathExp(MacroAssembler* masm,
} } // namespace v8::internal
-#endif // V8_TARGET_ARCH_A64
+#endif // V8_TARGET_ARCH_ARM64
« no previous file with comments | « src/arm64/codegen-arm64.h ('k') | src/arm64/constants-arm64.h » ('j') | no next file with comments »

Powered by Google App Engine
@@ -546,7 +546,7 @@ void MathExpGenerator::EmitMathExp(MacroAssembler* masm,
// Continue the common case first. 'mi' tests N == 1.
__ B(&result_is_finite_non_zero, mi);
- // TODO(jbramley): Consider adding a +infinity register for A64.
+ // TODO(jbramley): Consider adding a +infinity register for ARM64.
__ Ldr(double_temp2, ExpConstant(constants, 2)); // Synthesize +infinity.
// Select between +0.0 and +infinity. 'lo' tests C == 0.
This is Rietveld 408576698